<?php

 /**
  * English language file for phpPgAdmin.  Use this as a basis
  * for new translations.
  *
  * $Id: arabic.php,v 1.6 2007/04/24 11:42:07 soranzo Exp $
  */

 // Language and character set
   $lang['applang'] = '&#1593;&#1585;&#1576;&#1610;';
 $lang['appcharset'] = 'UTF-8';
 $lang['applocale'] = 'ar';
 $lang['appdbencoding'] = 'UNICODE';
 $lang['applangdir'] = 'rtl';

 // Welcome
  $lang['strintro'] = '&#1605;&#1585;&#1581;&#1576;&#1575; &#1575;&#1604;&#1609; phpPgAdmin.';
  $lang['strppahome'] = '&#1605;&#1608;&#1602;&#1593; phpPgAdmin';
  $lang['strpgsqlhome'] = '&#1605;&#1608;&#1602;&#1593; PostgreSQL';
 $lang['strpgsqlhome_url'] = 'http://www.postgresql.org/';
 $lang['strlocaldocs'] = '&#1578;&#1593;&#1604;&#1610;&#1605;&#1575;&#1578; PostgreSQL (&#1605;&#1581;&#1604;&#1610;&#1577;)';
 $lang['strreportbug'] = '&#1575;&#1604;&#1573;&#1576;&#1604;&#1575;&#1594; &#1593;&#1606; &#1582;&#1591;&#1571; &#1601;&#1610; &#1575;&#1604;&#1576;&#1585;&#1606;&#1575;&#1605;&#1580;.';
 $lang['strviewfaq'] = '&#1602;&#1585;&#1575;&#1569;&#1577; &#1575;&#1604;&#1571;&#1587;&#1574;&#1604;&#1577; &#1575;&#1604;&#1605;&#1578;&#1603;&#1585;&#1585;&#1577; &#1593;&#1604;&#1609; &#1575;&#1604;&#1605;&#1608;&#1602;&#1593;';
 $lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/?page=faq';
 
 // Basic strings
 $lang['strlogin'] = '&#1575;&#1604;&#1583;&#1582;&#1608;&#1604;';
$lang['strloginfailed'] = '&#1604;&#1605; &#1578;&#1606;&#1580;&#1581; &#1593;&#1605;&#1604;&#1610;&#1577; &#1575;&#1604;&#1583;&#1582;&#1608;&#1604;';
 $lang['strlogindisallowed'] = '&#1604;&#1575; &#1610;&#1587;&#1605;&#1581; &#1576;&#1575;&#1604;&#1583;&#1582;&#1608;&#1604; &#1576;&#1607;&#1584;&#1607; &#1575;&#1604;&#1591;&#1585;&#1610;&#1602;&#1577; &#1604;&#1571;&#1587;&#1576;&#1575;&#1576; &#1571;&#1605;&#1606;&#1610;&#1577;.';
 $lang['strserver'] = '&#1575;&#1604;&#1582;&#1575;&#1583;&#1605;';
 $lang['strlogout'] = '&#1582;&#1585;&#1608;&#1580;';
 $lang['strowner'] = '&#1605;&#1575;&#1604;&#1603; Owner';
 $lang['straction'] = '&#1573;&#1580;&#1585;&#1575;&#1569; Action';
 $lang['stractions'] = '&#1573;&#1580;&#1585;&#1575;&#1569;&#1575;&#1578; Actions';
 $lang['strname'] = '&#1575;&#1604;&#1573;&#1587;&#1605;';
 $lang['strdefinition'] = '&#1575;&#1604;&#1578;&#1593;&#1585;&#1610;&#1601;';
 $lang['strproperties'] = '&#1582;&#1589;&#1575;&#1574;&#1589;';
 $lang['strbrowse'] = '&#1573;&#1587;&#1578;&#1593;&#1585;&#1575;&#1590; Browse';
 $lang['strdrop'] = '&#1581;&#1584;&#1601; Drop';
 $lang['strdropped'] = '&#1605;&#1581;&#1584;&#1608;&#1601; Dropped';
 $lang['strnull'] = 'Null';
 $lang['strnotnull'] = '&#1604;&#1610;&#1587; Null';
 $lang['strprev'] = '&gt;&#1575;&#1604;&#1587;&#1575;&#1576;&#1602;';
 $lang['strnext'] = '&lt;&#1575;&#1604;&#1578;&#1575;&#1604;&#1610;';
 $lang['strfirst'] = '&gt;&gt;&#1575;&#1604;&#1571;&#1608;&#1604;';
 $lang['strlast'] = '&#1575;&#1604;&#1571;&#1582;&#1610;&#1585;&lt;&lt;';
 $lang['strfailed'] = '&#1601;&#1588;&#1600;&#1604;';
 $lang['strcreate'] = '&#1573;&#1606;&#1588;&#1575;&#1569;';
 $lang['strcreated'] = '&#1578;&#1605; &#1575;&#1604;&#1573;&#1606;&#1588;&#1575;&#1569;';
 $lang['strcomment'] = '&#1605;&#1604;&#1575;&#1581;&#1592;&#1575;&#1578;';
 $lang['strlength'] = '&#1591;&#1608;&#1604;';
 $lang['strdefault'] = '&#1575;&#1604;&#1573;&#1601;&#1578;&#1585;&#1575;&#1590;&#1610;';
 $lang['stralter'] = '&#1578;&#1593;&#1583;&#1610;&#1604;Alter';
 $lang['strok'] = '&#1605;&#1608;&#1575;&#1601;&#1602;';
 $lang['strcancel'] = '&#1578;&#1585;&#1575;&#1580;&#1593;';
 $lang['strsave'] = '&#1581;&#1601;&#1592;';
 $lang['strreset'] = '&#1573;&#1593;&#1575;&#1583;&#1577; Reset';
 $lang['strinsert'] = '&#1573;&#1583;&#1585;&#1575;&#1580; Insert';
 $lang['strselect'] = '&#1573;&#1582;&#1578;&#1610;&#1575;&#1585; Select';
 $lang['strdelete'] = '&#1581;&#1584;&#1601; Delete';
 $lang['strupdate'] = '&#1578;&#1593;&#1583;&#1610;&#1604; Update';
 $lang['strreferences'] = '&#1605;&#1585;&#1575;&#1580;&#1593;';
 $lang['stryes'] = '&#1606;&#1593;&#1605;';
 $lang['strno'] = '&#1604;&#1575;';
 $lang['strtrue'] = '&#1589;&#1581;&#1610;&#1581; TRUE';
 $lang['strfalse'] = '&#1582;&#1575;&#1591;&#1574; FALSE';
 $lang['stredit'] = '&#1578;&#1581;&#1585;&#1610;&#1585;';
 $lang['strcolumns'] = '&#1571;&#1593;&#1605;&#1583;&#1577; Columns';
 $lang['strrows'] = '&#1587;&#1580;&#1604;/&#1587;&#1580;&#1604;&#1575;&#1578;';
 $lang['strrowsaff'] = '&#1587;&#1580;&#1604; &#1578;&#1571;&#1579;&#1585;/&#1587;&#1580;&#1604;&#1575;&#1578; &#1578;&#1571;&#1579;&#1585;&#1578;';
 $lang['strobjects'] = 'object(s)';
 $lang['strexample'] = '&#1605;&#1579;&#1604;&#1575;';
 $lang['strback'] = '&#1585;&#1580;&#1608;&#1593; &#1604;&#1604;&#1582;&#1604;&#1601;';
 $lang['strqueryresults'] = '&#1606;&#1578;&#1575;&#1574;&#1580; &#1575;&#1604;&#1573;&#1587;&#1578;&#1593;&#1604;&#1575;&#1605;';
 $lang['strshow'] = '&#1575;&#1593;&#1585;&#1590;';
 $lang['strempty'] = '&#1573;&#1601;&#1585;&#1575;&#1594; Empty';
 $lang['strlanguage'] = '&#1575;&#1604;&#1604;&#1594;&#1577;';
 $lang['strencoding'] = '&#1575;&#1604;&#1588;&#1610;&#1601;&#1585;&#1577; Encoding';
 $lang['strvalue'] = '&#1575;&#1604;&#1602;&#1610;&#1605;&#1577; Value';
 $lang['strunique'] = '&#1601;&#1585;&#1610;&#1583; Unique';
 $lang['strprimary'] = '&#1585;&#1574;&#1610;&#1587;&#1610; Primary';
 $lang['strexport'] = '&#1578;&#1589;&#1583;&#1610;&#1585; Export';
 $lang['strimport'] = '&#1573;&#1587;&#1578;&#1610;&#1585;&#1575;&#1583; Import';
 $lang['strsql'] = 'SQL';
 $lang['strgo'] = 'Go';
 $lang['stradmin'] = '&#1573;&#1583;&#1575;&#1585;&#1577; Admin';
 $lang['strvacuum'] = 'Vacuum';
 $lang['stranalyze'] = 'Analyze';
 $lang['strclusterindex'] = 'Cluster';
 $lang['strclustered'] = 'Clustered?';
 $lang['strreindex'] = 'Reindex';
 $lang['strrun'] = 'Run';
 $lang['stradd'] = '&#1573;&#1590;&#1575;&#1601;&#1577;';
 $lang['strevent'] = 'Event';
 $lang['strwhere'] = 'Where';
 $lang['strinstead'] = 'Do Instead';
 $lang['strwhen'] = 'When';
 $lang['strformat'] = 'Format';
 $lang['strdata'] = 'Data';
 $lang['strconfirm'] = '&#1578;&#1571;&#1603;&#1610;&#1583;';
 $lang['strexpression'] = '&#1578;&#1593;&#1576;&#1610;&#1585;';
 $lang['strellipsis'] = '...';
 $lang['strseparator'] = ': ';
 $lang['strexpand'] = '&#1573;&#1601;&#1578;&#1581;';
 $lang['strcollapse'] = '&#1587;&#1603;&#1617;&#1585;';
 $lang['strexplain'] = 'Explain';
 $lang['strexplainanalyze'] = 'Explain Analyze';
 $lang['strfind'] = '&#1576;&#1581;&#1579;';
 $lang['stroptions'] = '&#1582;&#1610;&#1575;&#1585;&#1575;&#1578;';
 $lang['strrefresh'] = '&#1578;&#1581;&#1583;&#1610;&#1579; Refresh';
 $lang['strdownload'] = '&#1578;&#1606;&#1586;&#1610;&#1604;';
 $lang['strdownloadgzipped'] = '&#1578;&#1606;&#1586;&#1610;&#1604; &#1593;&#1604;&#1609; &#1588;&#1603;&#1604; &#1605;&#1604;&#1601; &#1605;&#1590;&#1594;&#1608;&#1591; &#1576;&#1600; gzip';
 $lang['strinfo'] = 'Info';
 $lang['stroids'] = 'OIDs';
 $lang['stradvanced'] = 'Advanced';
 $lang['strvariables'] = 'Variables';
 $lang['strprocess'] = '&#1575;&#1604;&#1593;&#1605;&#1604;&#1610;&#1577; Process';
 $lang['strprocesses'] = '&#1575;&#1604;&#1593;&#1605;&#1604;&#1610;&#1575;&#1578; Processes';
 $lang['strsetting'] = 'Setting';
 $lang['streditsql'] = 'Edit SQL';
 $lang['strruntime'] = 'Total runtime: %s ms';
 $lang['strpaginate'] = 'Paginate results';
 $lang['struploadscript'] = 'or upload an SQL script:';
 $lang['strstarttime'] = 'Start Time';
 $lang['strfile'] = '&#1605;&#1604;&#1601;';
 $lang['strfileimported'] = '&#1578;&#1605; &#1575;&#1587;&#1578;&#1610;&#1585;&#1575;&#1583; &#1575;&#1604;&#1605;&#1604;&#1601;.';

 // Error handling
 $lang['strbadconfig'] = '&#1573;&#1606; &#1575;&#1604;&#1605;&#1604;&#1601; config.inc.php &#1575;&#1604;&#1584;&#1610; &#1604;&#1583;&#1610;&#1603; &#1575;&#1589;&#1576;&#1581; &#1602;&#1583;&#1610;&#1605;&#1575;. &#1587;&#1578;&#1581;&#1578;&#1575;&#1580; &#1575;&#1604;&#1609; &#1573;&#1593;&#1575;&#1583;&#1577; &#1578;&#1608;&#1604;&#1610;&#1583;&#1607; &#1605;&#1606; &#1575;&#1604;&#1605;&#1604;&#1601; &#1575;&#1604;&#1580;&#1583;&#1610;&#1583; config.inc.php-dist.';
 $lang['strnotloaded'] = '&#1573;&#1606; &#1575;&#1593;&#1583;&#1575;&#1583;  PHP &#1575;&#1604;&#1605;&#1608;&#1580;&#1608;&#1583; &#1593;&#1604;&#1609; &#1607;&#1584;&#1575; &#1575;&#1604;&#1582;&#1575;&#1583;&#1605; &#1604;&#1575;&#1578;&#1583;&#1593;&#1605; PostgreSQL. &#1578;&#1581;&#1578;&#1575;&#1580; &#1575;&#1604;&#1609; &#1575;&#1593;&#1575;&#1583;&#1577; &#1578;&#1579;&#1576;&#1610;&#1578; PHP &#1576;&#1573;&#1587;&#1578;&#1582;&#1583;&#1575;&#1605; &#1575;&#1604;&#1582;&#1610;&#1575;&#1585;  --with-pgsql configure option.';
 $lang['strpostgresqlversionnotsupported'] = '&#1607;&#1584;&#1575; &#1575;&#1604;&#1575;&#1589;&#1583;&#1575;&#1585; &#1605;&#1606; PostgreSQL &#1594;&#1610;&#1585; &#1605;&#1583;&#1593;&#1608;&#1605;. &#1575;&#1604;&#1585;&#1580;&#1575;&#1569; &#1575;&#1604;&#1578;&#1585;&#1602;&#1610;&#1577; &#1575;&#1604;&#1609; &#1575;&#1604;&#1573;&#1589;&#1583;&#1575;&#1585; %s &#1575;&#1608; &#1571;&#1593;&#1604;&#1609;.';
 $lang['strbadschema'] = 'Invalid schema specified.';
 $lang['strbadencoding'] = '&#1604;&#1602;&#1583; &#1601;&#1588;&#1604; &#1590;&#1576;&#1591; &#1588;&#1610;&#1601;&#1585;&#1577; &#1575;&#1604;&#1593;&#1605;&#1610;&#1604; client encoding &#1601;&#1610; &#1602;&#1575;&#1593;&#1583;&#1577; &#1575;&#1604;&#1576;&#1610;&#1575;&#1606;&#1575;&#1578;.';
 $lang['strsqlerror'] = '&#1582;&#1591;&#1571; SQL:';
 $lang['strinstatement'] = '&#1601;&#1610; &#1575;&#1604;&#1580;&#1605;&#1604;&#1577; statement:';
 $lang['strinvalidparam'] = 'Invalid script parameters.';
 $lang['strnodata'] = '&#1604;&#1605; &#1578;&#1608;&#1580;&#1583; &#1587;&#1580;&#1604;&#1575;&#1578;.';
 $lang['strnoobjects'] = '&#1604;&#1605; &#1578;&#1608;&#1580;&#1583; &#1603;&#1575;&#1574;&#1606;&#1575;&#1578;.';
 $lang['strrownotunique'] = '&#1604;&#1575; &#1610;&#1608;&#1580;&#1583; &#1605;&#1593;&#1585;&#1617;&#1601; &#1601;&#1585;&#1610;&#1583; unique identifier &#1601;&#1610; &#1607;&#1584;&#1575; &#1575;&#1604;&#1587;&#1580;&#1604;.';
 $lang['strnoreportsdb'] = '&#1604;&#1605; &#1578;&#1602;&#1605; &#1576;&#1573;&#1606;&#1588;&#1575;&#1569; &#1602;&#1575;&#1593;&#1583;&#1577; &#1576;&#1610;&#1575;&#1606;&#1575;&#1578; &#1575;&#1604;&#1578;&#1602;&#1575;&#1585;&#1610;&#1585; reports database. &#1573;&#1602;&#1585;&#1571; &#1575;&#1604;&#1578;&#1593;&#1604;&#1610;&#1605;&#1575;&#1578; &#1601;&#1610; &#1575;&#1604;&#1605;&#1601; INSTALL.';
 $lang['strnouploads'] = '&#1578;&#1581;&#1605;&#1610;&#1604; &#1575;&#1604;&#1605;&#1604;&#1601;&#1575;&#1578; &#1594;&#1610;&#1585; &#1605;&#1601;&#1593;&#1617;&#1604;.';
 $lang['strimporterror'] = '&#1582;&#1591;&#1571; &#1601;&#1610; &#1575;&#1604;&#1573;&#1587;&#1578;&#1610;&#1585;&#1575;&#1583;.';
 $lang['strimporterrorline'] = '&#1582;&#1591;&#1571; &#1601;&#1610; &#1575;&#1604;&#1573;&#1587;&#1578;&#1610;&#1585;&#1575;&#1583; &#1593;&#1606;&#1583; &#1575;&#1604;&#1587;&#1591;&#1585;: %s.';

 // Tables
 $lang['strtable'] = '&#1580;&#1583;&#1608;&#1604; Table';
 $lang['strtables'] = '&#1580;&#1583;&#1575;&#1608;&#1604; Tables';
 $lang['strshowalltables'] = '&#1571;&#1593;&#1585;&#1590; &#1580;&#1605;&#1610;&#1593; &#1575;&#1604;&#1580;&#1583;&#1575;&#1608;&#1604; Tables.';
 $lang['strnotables'] = '&#1604;&#1575; &#1610;&#1608;&#1580;&#1583; &#1580;&#1583;&#1575;&#1608;&#1604;.';
 $lang['strnotable'] = '&#1604;&#1575; &#1610;&#1608;&#1580;&#1583; &#1580;&#1583;&#1608;&#1604;.';
 $lang['strcreatetable'] = '&#1573;&#1606;&#1588;&#1575;&#1569; &#1580;&#1583;&#1608;&#1604; Table &#1580;&#1583;&#1610;&#1583;.';
 $lang['strtablename'] = '&#1573;&#1587;&#1605; &#1575;&#1604;&#1580;&#1583;&#1608;&#1604;';
 $lang['strtableneedsname'] = '&#1610;&#1580;&#1576; &#1573;&#1593;&#1591;&#1575;&#1569; &#1573;&#1587;&#1605; &#1604;&#1604;&#1580;&#1583;&#1608;&#1604;.';
 $lang['strtableneedsfield'] = '&#1610;&#1580;&#1576; &#1593;&#1604;&#1610;&#1603; &#1578;&#1581;&#1583;&#1610;&#1583; &#1593;&#1604;&#1609; &#1575;&#1604;&#1571;&#1602;&#1604; &#1581;&#1602;&#1604; &#1608;&#1575;&#1581;&#1583;.';
 $lang['strtableneedscols'] = '&#1575;&#1604;&#1580;&#1583;&#1575;&#1608;&#1604; &#1578;&#1578;&#1591;&#1604;&#1576; &#1593;&#1583;&#1583; &#1605;&#1602;&#1576;&#1608;&#1604; &#1605;&#1606; &#1575;&#1604;&#1571;&#1593;&#1605;&#1583;&#1577;.';
 $lang['strtablecreated'] = '&#1604;&#1602;&#1583; &#1578;&#1605; &#1573;&#1606;&#1588;&#1575;&#1569; &#1575;&#1604;&#1580;&#1583;&#1608;&#1604; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strtablecreatedbad'] = '&#1604;&#1602;&#1583; &#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1573;&#1606;&#1588;&#1575;&#1569; &#1575;&#1604;&#1580;&#1583;&#1608;&#1604;.';
 $lang['strconfdroptable'] = '&#1607;&#1604; &#1575;&#1606;&#1578; &#1605;&#1578;&#1571;&#1603;&#1583; &#1578;&#1585;&#1610;&#1583; &#1581;&#1584;&#1601; &#1575;&#1604;&#1580;&#1583;&#1608;&#1604; &#1576;&#1573;&#1587;&#1605; &quot;%s&quot;&#1567;';
 $lang['strtabledropped'] = '&#1604;&#1602;&#1583; &#1578;&#1605; &#1581;&#1584;&#1601; &#1575;&#1604;&#1580;&#1583;&#1608;&#1604;.';
 $lang['strtabledroppedbad'] = '&#1604;&#1602;&#1583; &#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1581;&#1584;&#1601; &#1575;&#1604;&#1580;&#1583;&#1608;&#1604;.';
 $lang['strconfemptytable'] = '&#1607;&#1604; &#1575;&#1606;&#1578; &#1605;&#1578;&#1571;&#1603;&#1583; &#1578;&#1585;&#1610;&#1583; &#1575;&#1601;&#1585;&#1575;&#1594; &#1605;&#1581;&#1578;&#1608;&#1610;&#1575;&#1578; &#1575;&#1604;&#1580;&#1583;&#1608;&#1604; &quot;%s&quot;&#1567;';
 $lang['strtableemptied'] = '&#1604;&#1602;&#1583; &#1578;&#1605; &#1575;&#1601;&#1585;&#1575;&#1594; &#1605;&#1581;&#1578;&#1608;&#1610;&#1575;&#1578; &#1575;&#1604;&#1580;&#1583;&#1608;&#1604; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strtableemptiedbad'] = '&#1604;&#1602;&#1583; &#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1573;&#1601;&#1585;&#1575;&#1594; &#1605;&#1581;&#1578;&#1608;&#1610;&#1575;&#1578; &#1575;&#1604;&#1580;&#1583;&#1608;&#1604;.';
 $lang['strinsertrow'] = '&#1573;&#1583;&#1585;&#1575;&#1580; &#1587;&#1580;&#1604;.';
 $lang['strrowinserted'] = '&#1604;&#1602;&#1583; &#1578;&#1605; &#1573;&#1583;&#1585;&#1575;&#1580; &#1575;&#1604;&#1587;&#1580;&#1604; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strrowinsertedbad'] = '&#1604;&#1602;&#1583; &#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1573;&#1583;&#1585;&#1575;&#1580; &#1575;&#1604;&#1587;&#1580;&#1604;.';
 $lang['streditrow'] = '&#1578;&#1581;&#1585;&#1610;&#1585; &#1575;&#1604;&#1587;&#1580;&#1604;.';
 $lang['strrowupdated'] = '&#1578;&#1605; &#1578;&#1593;&#1583;&#1610;&#1604; &#1575;&#1604;&#1587;&#1580;&#1604; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strrowupdatedbad'] = '&#1604;&#1602;&#1583; &#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1578;&#1593;&#1583;&#1610;&#1604; &#1575;&#1604;&#1587;&#1580;&#1604;.';
 $lang['strdeleterow'] = '&#1573;&#1581;&#1584;&#1601; &#1575;&#1604;&#1587;&#1580;&#1604;.';
 $lang['strconfdeleterow'] = '&#1607;&#1604; &#1575;&#1606;&#1578; &#1605;&#1578;&#1571;&#1603;&#1583; &#1578;&#1585;&#1610;&#1583; &#1581;&#1584;&#1601; &#1607;&#1584;&#1575; &#1575;&#1604;&#1587;&#1580;&#1604;&#1567;';
 $lang['strrowdeleted'] = '&#1604;&#1602;&#1583; &#1578;&#1605; &#1581;&#1584;&#1601; &#1575;&#1604;&#1587;&#1580;&#1604; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strrowdeletedbad'] = '&#1604;&#1602;&#1583; &#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1581;&#1584;&#1601; &#1575;&#1604;&#1587;&#1580;&#1604;.';
 $lang['strinsertandrepeat'] = '&#1573;&#1583;&#1585;&#1575;&#1580; &#1608; &#1573;&#1593;&#1575;&#1583;&#1577;';
 $lang['strfield'] = '&#1575;&#1604;&#1581;&#1602;&#1604;';
 $lang['strnumfields'] = '&#1593;&#1583;&#1583; &#1575;&#1604;&#1581;&#1602;&#1608;&#1604;';
 $lang['strselectallfields'] = '&#1573;&#1582;&#1578;&#1610;&#1575;&#1585; &#1580;&#1605;&#1610;&#1593; &#1575;&#1604;&#1581;&#1602;&#1608;&#1604;';
 $lang['strselectneedscol'] = '&#1578;&#1581;&#1578;&#1575;&#1580; &#1593;&#1585;&#1590; &#1593;&#1604;&#1609; &#1575;&#1604;&#1571;&#1602;&#1604; &#1593;&#1605;&#1608;&#1583; &#1608;&#1575;&#1581;&#1583;.';
 $lang['strselectunary'] = '&#1575;&#1604;&#1593;&#1605;&#1604;&#1610;&#1575;&#1578; &#1575;&#1604;&#1571;&#1581;&#1575;&#1583;&#1610;&#1577; Unary operators &#1604;&#1575; &#1610;&#1605;&#1603;&#1606; &#1575;&#1606; &#1610;&#1603;&#1608;&#1606; &#1604;&#1607;&#1575; &#1602;&#1610;&#1605;.';
 $lang['straltercolumn'] = '&#1578;&#1593;&#1583;&#1610;&#1604; &#1575;&#1604;&#1593;&#1605;&#1608;&#1583;';
 $lang['strcolumnaltered'] = '&#1604;&#1602;&#1583; &#1578;&#1605; &#1578;&#1593;&#1583;&#1610;&#1604; &#1575;&#1604;&#1593;&#1605;&#1608;&#1583; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strcolumnalteredbad'] = '&#1604;&#1602;&#1583; &#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1578;&#1593;&#1583;&#1610;&#1604; &#1575;&#1604;&#1593;&#1605;&#1608;&#1583;.';
 $lang['strconfdropcolumn'] = '&#1607;&#1604; &#1575;&#1606;&#1578; &#1605;&#1578;&#1571;&#1603;&#1583; &#1578;&#1585;&#1610;&#1583; &#1581;&#1584;&#1601; &#1575;&#1604;&#1593;&#1605;&#1608;&#1583; &quot;%s&quot; &#1605;&#1606; &#1575;&#1604;&#1580;&#1583;&#1608;&#1604; &quot;%s&quot;&#1567;';
 $lang['strcolumndropped'] = '&#1604;&#1602;&#1583; &#1578;&#1605; &#1581;&#1584;&#1601; &#1575;&#1604;&#1593;&#1605;&#1608;&#1583; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strcolumndroppedbad'] = '&#1604;&#1602;&#1583; &#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1581;&#1584;&#1601; &#1575;&#1604;&#1593;&#1605;&#1608;&#1583;.';
 $lang['straddcolumn'] = '&#1573;&#1590;&#1575;&#1601;&#1577; &#1593;&#1605;&#1608;&#1583;.';
 $lang['strcolumnadded'] = '&#1604;&#1602;&#1583; &#1578;&#1605;&#1578; &#1573;&#1590;&#1575;&#1601;&#1577; &#1575;&#1604;&#1593;&#1605;&#1608;&#1583; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strcolumnaddedbad'] = '&#1604;&#1602;&#1583; &#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1573;&#1590;&#1575;&#1601;&#1577; &#1575;&#1604;&#1593;&#1605;&#1608;&#1583;.';
 $lang['strcascade'] = 'CASCADE';
 $lang['strtablealtered'] = '&#1604;&#1602;&#1583; &#1578;&#1605; &#1578;&#1593;&#1583;&#1610;&#1604; &#1575;&#1604;&#1580;&#1583;&#1608;&#1604; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strtablealteredbad'] = '&#1604;&#1602;&#1583; &#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1578;&#1593;&#1583;&#1610;&#1604; &#1575;&#1604;&#1580;&#1583;&#1608;&#1604;.';
 $lang['strdataonly'] = '&#1575;&#1604;&#1576;&#1610;&#1575;&#1606;&#1575;&#1578; &#1601;&#1602;&#1591;';
 $lang['strstructureonly'] = '&#1575;&#1604;&#1607;&#1610;&#1603;&#1604;&#1610;&#1577; &#1601;&#1602;&#1591;';
 $lang['strstructureanddata'] = '&#1575;&#1604;&#1607;&#1610;&#1603;&#1604;&#1610;&#1577; &#1608;&#1575;&#1604;&#1576;&#1610;&#1575;&#1606;&#1575;&#1578;';
 $lang['strtabbed'] = 'Tabbed';
 $lang['strauto'] = 'Auto';

 // Users
 $lang['struser'] = '&#1575;&#1604;&#1605;&#1587;&#1578;&#1582;&#1583;&#1605;';
 $lang['strusers'] = '&#1575;&#1604;&#1605;&#1587;&#1578;&#1582;&#1583;&#1605;&#1610;&#1606;';
 $lang['strusername'] = '&#1573;&#1587;&#1605; &#1575;&#1604;&#1605;&#1587;&#1578;&#1582;&#1583;&#1605;';
 $lang['strpassword'] = '&#1603;&#1604;&#1605;&#1577; &#1575;&#1604;&#1587;&#1585;';
 $lang['strsuper'] = '&#1605;&#1587;&#1578;&#1582;&#1583;&#1605; &#1584;&#1608; &#1589;&#1604;&#1575;&#1581;&#1610;&#1617;&#1575;&#1578; &#1593;&#1604;&#1610;&#1575;&#1567;';
 $lang['strcreatedb'] = '&#1573;&#1606;&#1588;&#1575;&#1569; &#1602;&#1575;&#1593;&#1583;&#1577; &#1576;&#1610;&#1575;&#1606;&#1575;&#1578;&#1567;';
 $lang['strexpires'] = '&#1610;&#1606;&#1578;&#1607;&#1610;';
 $lang['strsessiondefaults'] = 'Session defaults';
 $lang['strnousers'] = '&#1604;&#1605; &#1610;&#1608;&#1580;&#1583; &#1605;&#1587;&#1578;&#1582;&#1583;&#1605;&#1610;&#1606;.';
 $lang['struserupdated'] = '&#1578;&#1605; &#1578;&#1593;&#1583;&#1610;&#1604; &#1575;&#1604;&#1605;&#1587;&#1578;&#1582;&#1583;&#1605; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['struserupdatedbad'] = '&#1601;&#1588;&#1604; &#1578;&#1593;&#1583;&#1610;&#1604; &#1575;&#1604;&#1605;&#1587;&#1578;&#1582;&#1583;&#1605;.';
 $lang['strshowallusers'] = '&#1593;&#1585;&#1590; &#1580;&#1605;&#1610;&#1593; &#1575;&#1604;&#1605;&#1587;&#1578;&#1582;&#1583;&#1605;&#1610;&#1606;';
 $lang['strcreateuser'] = '&#1573;&#1590;&#1575;&#1601;&#1577; &#1605;&#1587;&#1578;&#1582;&#1583;&#1605; &#1580;&#1583;&#1610;&#1583;';
 $lang['struserneedsname'] = '&#1610;&#1580;&#1576; &#1573;&#1593;&#1591;&#1575;&#1569; &#1573;&#1587;&#1605; &#1604;&#1604;&#1605;&#1587;&#1578;&#1582;&#1583;&#1605;.';
 $lang['strusercreated'] = '&#1578;&#1605;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1573;&#1590;&#1575;&#1601;&#1577; &#1575;&#1604;&#1605;&#1587;&#1578;&#1582;&#1583;&#1605; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strusercreatedbad'] = '&#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1573;&#1590;&#1575;&#1601;&#1577; &#1575;&#1604;&#1605;&#1587;&#1578;&#1582;&#1583;&#1605;.';
 $lang['strconfdropuser'] = '&#1607;&#1604; &#1575;&#1606;&#1578; &#1605;&#1578;&#1571;&#1603;&#1583; &#1578;&#1585;&#1610;&#1583; &#1581;&#1584;&#1601; &#1575;&#1604;&#1605;&#1587;&#1578;&#1582;&#1583;&#1605; &quot;%s&quot;&#1567;';
 $lang['struserdropped'] = '&#1578;&#1605; &#1581;&#1584;&#1601; &#1575;&#1604;&#1605;&#1587;&#1578;&#1582;&#1583;&#1605; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['struserdroppedbad'] = '&#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1581;&#1584;&#1601; &#1575;&#1604;&#1605;&#1587;&#1578;&#1582;&#1583;&#1605;.';
 $lang['straccount'] = 'Account';
 $lang['strchangepassword'] = '&#1578;&#1594;&#1610;&#1610;&#1585; &#1603;&#1604;&#1605;&#1577; &#1575;&#1604;&#1587;&#1585;';
 $lang['strpasswordchanged'] = '&#1578;&#1605; &#1578;&#1594;&#1610;&#1610;&#1585; &#1603;&#1604;&#1605;&#1577; &#1575;&#1604;&#1587;&#1585; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strpasswordchangedbad'] = '&#1604;&#1605; &#1610;&#1606;&#1580;&#1581; &#1578;&#1594;&#1610;&#1610;&#1585; &#1603;&#1604;&#1605;&#1577; &#1575;&#1604;&#1587;&#1585;.';
 $lang['strpasswordshort'] = '&#1603;&#1604;&#1605;&#1577; &#1575;&#1604;&#1587;&#1585; &#1571;&#1602;&#1589;&#1585; &#1605;&#1606; &#1575;&#1604;&#1581;&#1583; &#1575;&#1604;&#1571;&#1583;&#1606;&#1609;.';
 $lang['strpasswordconfirm'] = '&#1603;&#1604;&#1605;&#1577; &#1575;&#1604;&#1587;&#1585; &#1575;&#1604;&#1605;&#1583;&#1582;&#1604;&#1577; &#1604;&#1605; &#1578;&#1578;&#1591;&#1575;&#1576;&#1602; &#1605;&#1593; &#1578;&#1571;&#1603;&#1610;&#1583; &#1603;&#1604;&#1605;&#1577; &#1575;&#1604;&#1587;&#1585;.';
 
 // Groups
 $lang['strgroup'] = '&#1575;&#1604;&#1605;&#1580;&#1605;&#1608;&#1593;&#1577;';
 $lang['strgroups'] = '&#1575;&#1604;&#1605;&#1580;&#1605;&#1608;&#1593;&#1575;&#1578;';
 $lang['strnogroup'] = '&#1604;&#1605; &#1578;&#1608;&#1580;&#1583; &#1575;&#1604;&#1605;&#1580;&#1605;&#1608;&#1593;&#1577;.';
 $lang['strnogroups'] = '&#1604;&#1605; &#1578;&#1608;&#1580;&#1583; &#1605;&#1580;&#1605;&#1608;&#1593;&#1575;&#1578;.';
 $lang['strcreategroup'] = '&#1573;&#1590;&#1575;&#1601;&#1577; &#1605;&#1580;&#1605;&#1608;&#1593;&#1577; &#1580;&#1583;&#1610;&#1583;&#1577;';
 $lang['strshowallgroups'] = '&#1593;&#1585;&#1590; &#1580;&#1605;&#1610;&#1593; &#1575;&#1604;&#1605;&#1580;&#1605;&#1608;&#1593;&#1575;&#1578;';
 $lang['strgroupneedsname'] = '&#1610;&#1580;&#1576; &#1573;&#1593;&#1591;&#1575;&#1569; &#1573;&#1587;&#1605; &#1604;&#1604;&#1605;&#1580;&#1605;&#1608;&#1593;&#1577;.';
 $lang['strgroupcreated'] = '&#1604;&#1602;&#1583; &#1578;&#1605;&#1578; &#1573;&#1590;&#1575;&#1601;&#1577; &#1575;&#1604;&#1605;&#1580;&#1605;&#1608;&#1593;&#1577; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strgroupcreatedbad'] = '&#1604;&#1602;&#1583; &#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1573;&#1590;&#1575;&#1601;&#1577; &#1575;&#1604;&#1605;&#1580;&#1605;&#1608;&#1593;&#1577;.'; 
 $lang['strconfdropgroup'] = '&#1607;&#1604; &#1575;&#1606;&#1578; &#1605;&#1578;&#1571;&#1603;&#1583; &#1578;&#1585;&#1610;&#1583; &#1581;&#1584;&#1601; &#1575;&#1604;&#1605;&#1580;&#1605;&#1608;&#1593;&#1577; &quot;%s&quot;&#1567;';
 $lang['strgroupdropped'] = '&#1578;&#1605; &#1581;&#1584;&#1601; &#1575;&#1604;&#1605;&#1580;&#1605;&#1608;&#1593;&#1577; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strgroupdroppedbad'] = '&#1604;&#1602;&#1583; &#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1581;&#1584;&#1601; &#1575;&#1604;&#1605;&#1580;&#1605;&#1608;&#1593;&#1577;.';
 $lang['strmembers'] = '&#1575;&#1604;&#1571;&#1593;&#1590;&#1575;&#1569;';
 $lang['straddmember'] = '&#1573;&#1590;&#1575;&#1601;&#1577; &#1593;&#1590;&#1608;';
 $lang['strmemberadded'] = '&#1578;&#1605;&#1578; &#1573;&#1590;&#1575;&#1601;&#1577; &#1575;&#1604;&#1593;&#1590;&#1608;.';
 $lang['strmemberaddedbad'] = '&#1604;&#1602;&#1583; &#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1573;&#1590;&#1575;&#1601;&#1577; &#1575;&#1604;&#1593;&#1590;&#1608;.';
 $lang['strdropmember'] = '&#1581;&#1584;&#1601; &#1593;&#1590;&#1608;';
 $lang['strconfdropmember'] = '&#1607;&#1604; &#1571;&#1606;&#1578; &#1605;&#1578;&#1571;&#1603;&#1583; &#1578;&#1585;&#1610;&#1583; &#1581;&#1584;&#1601; &#1575;&#1604;&#1593;&#1590;&#1608; &quot;%s&quot; &#1605;&#1606; &#1575;&#1604;&#1605;&#1580;&#1605;&#1608;&#1593;&#1577; &quot;%s&quot;&#1567;';
 $lang['strmemberdropped'] = '&#1578;&#1605; &#1581;&#1584;&#1601; &#1575;&#1604;&#1593;&#1590;&#1608;.';
 $lang['strmemberdroppedbad'] = '&#1604;&#1602;&#1583; &#1601;&#1588;&#1604; &#1581;&#1584;&#1601; &#1575;&#1604;&#1593;&#1590;&#1608;.';

 // Privileges
 $lang['strprivilege'] = '&#1575;&#1604;&#1589;&#1604;&#1575;&#1581;&#1610;&#1617;&#1577;';
 $lang['strprivileges'] = '&#1575;&#1604;&#1589;&#1604;&#1575;&#1581;&#1610;&#1575;&#1578;';
 $lang['strnoprivileges'] = '&#1607;&#1584;&#1575; &#1575;&#1604;&#1603;&#1575;&#1574;&#1606; &#1604;&#1583;&#1610;&#1607; &#1589;&#1604;&#1575;&#1581;&#1610;&#1617;&#1575;&#1578; &#1575;&#1604;&#1605;&#1575;&#1604;&#1603; &#1575;&#1604;&#1573;&#1601;&#1578;&#1585;&#1575;&#1590;&#1610;&#1577;.';
 $lang['strgrant'] = '&#1578;&#1589;&#1585;&#1610;&#1581; Grant';
 $lang['strrevoke'] = '&#1587;&#1581;&#1576; Revoke';
 $lang['strgranted'] = '&#1578;&#1605; &#1578;&#1594;&#1610;&#1610;&#1585; &#1575;&#1604;&#1589;&#1604;&#1575;&#1581;&#1610;&#1575;&#1578;.';
 $lang['strgrantfailed'] = '&#1604;&#1602;&#1583; &#1601;&#1588;&#1604; &#1578;&#1594;&#1610;&#1610;&#1585; &#1575;&#1604;&#1589;&#1604;&#1575;&#1581;&#1610;&#1575;&#1578;.';
 $lang['strgrantbad'] = '&#1610;&#1580;&#1576; &#1593;&#1604;&#1610;&#1603; &#1578;&#1581;&#1583;&#1610;&#1583; &#1593;&#1604;&#1609; &#1575;&#1604;&#1575;&#1602;&#1604; &#1605;&#1587;&#1578;&#1582;&#1583;&#1605; &#1608;&#1575;&#1581;&#1583; &#1575;&#1608; &#1605;&#1580;&#1605;&#1608;&#1593;&#1577; &#1608;&#1575;&#1581;&#1583;&#1577; &#1608; &#1593;&#1604;&#1609; &#1575;&#1604;&#1571;&#1602;&#1604; &#1589;&#1604;&#1575;&#1581;&#1610;&#1617;&#1577; &#1608;&#1575;&#1581;&#1583;&#1577;.';
 $lang['strgrantor'] = '&#1575;&#1604;&#1605;&#1589;&#1585;&#1617;&#1581; Grantor';
 $lang['strasterisk'] = '*';

 // Databases
 $lang['strdatabase'] = '&#1602;&#1575;&#1593;&#1583;&#1577; &#1576;&#1610;&#1575;&#1606;&#1575;&#1578;';
 $lang['strdatabases'] = '&#1602;&#1608;&#1575;&#1593;&#1583; &#1575;&#1604;&#1576;&#1610;&#1575;&#1606;&#1575;&#1578;';
 $lang['strshowalldatabases'] = '&#1593;&#1585;&#1590; &#1580;&#1605;&#1610;&#1593; &#1602;&#1608;&#1575;&#1593;&#1583; &#1575;&#1604;&#1576;&#1610;&#1575;&#1606;&#1575;&#1578;';
 $lang['strnodatabase'] = '&#1604;&#1605; &#1610;&#1608;&#1580;&#1583; &#1602;&#1575;&#1593;&#1583;&#1577; &#1576;&#1610;&#1575;&#1606;&#1575;&#1578;.';
 $lang['strnodatabases'] = '&#1604;&#1605; &#1610;&#1608;&#1580;&#1583; &#1602;&#1608;&#1575;&#1593;&#1583; &#1576;&#1610;&#1575;&#1606;&#1575;&#1578;.';
 $lang['strcreatedatabase'] = '&#1573;&#1606;&#1588;&#1575;&#1569; &#1602;&#1575;&#1593;&#1583;&#1577; &#1576;&#1610;&#1575;&#1606;&#1575;&#1578; &#1580;&#1583;&#1610;&#1583;&#1577;';
 $lang['strdatabasename'] = '&#1573;&#1587;&#1605; &#1602;&#1575;&#1593;&#1583;&#1577; &#1575;&#1604;&#1576;&#1610;&#1575;&#1606;&#1575;&#1578;';
 $lang['strdatabaseneedsname'] = '&#1610;&#1580;&#1576; &#1593;&#1604;&#1610;&#1603; &#1573;&#1593;&#1591;&#1575;&#1569; &#1573;&#1587;&#1605; &#1604;&#1602;&#1575;&#1593;&#1583;&#1577; &#1575;&#1604;&#1576;&#1610;&#1575;&#1606;&#1575;&#1578;.';
 $lang['strdatabasecreated'] = '&#1578;&#1605; &#1573;&#1606;&#1588;&#1575;&#1569; &#1602;&#1575;&#1593;&#1583;&#1577; &#1575;&#1604;&#1576;&#1610;&#1575;&#1606;&#1575;&#1578; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strdatabasecreatedbad'] = '&#1601;&#1588;&#1604; &#1573;&#1606;&#1588;&#1575;&#1569; &#1602;&#1575;&#1593;&#1583;&#1577; &#1575;&#1604;&#1576;&#1610;&#1575;&#1606;&#1575;&#1578;.';
 $lang['strconfdropdatabase'] = '&#1607;&#1604; &#1571;&#1606;&#1578; &#1605;&#1578;&#1571;&#1603;&#1583; &#1578;&#1585;&#1610;&#1583; &#1581;&#1584;&#1601; &#1602;&#1575;&#1593;&#1583;&#1577; &#1575;&#1604;&#1576;&#1610;&#1575;&#1606;&#1575;&#1578; &#1576;&#1573;&#1587;&#1605; &quot;%s&quot;?';
 $lang['strdatabasedropped'] = '&#1578;&#1605; &#1581;&#1584;&#1601; &#1602;&#1575;&#1593;&#1583;&#1577; &#1575;&#1604;&#1576;&#1610;&#1575;&#1606;&#1575;&#1578;.';
 $lang['strdatabasedroppedbad'] = '&#1604;&#1602;&#1583; &#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1581;&#1584;&#1601; &#1602;&#1575;&#1593;&#1583;&#1577; &#1575;&#1604;&#1576;&#1610;&#1575;&#1606;&#1575;&#1578;.';
 $lang['strentersql'] = '&#1571;&#1583;&#1582;&#1604; &#1575;&#1604;&#1600;SQL &#1575;&#1604;&#1584;&#1610; &#1578;&#1585;&#1610;&#1583; &#1573;&#1587;&#1578;&#1583;&#1593;&#1575;&#1569;&#1607; &#1607;&#1606;&#1575;:';
 $lang['strsqlexecuted'] = '&#1578;&#1605; &#1573;&#1587;&#1578;&#1583;&#1593;&#1575;&#1569; &#1575;&#1604;&#1600;SQL.';
 $lang['strvacuumgood'] = '&#1578;&#1605;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1575;&#1604;&#1600;Vacuum.';
 $lang['strvacuumbad'] = '&#1604;&#1602;&#1583; &#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1575;&#1604;&#1600;Vacuum.';
 $lang['stranalyzegood'] = '&#1578;&#1605;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1575;&#1604;&#1601;&#1581;&#1589;.';
 $lang['stranalyzebad'] = '&#1604;&#1602;&#1583; &#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1575;&#1604;&#1601;&#1581;&#1589;.';
 $lang['strreindexgood'] = '&#1578;&#1605;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1573;&#1593;&#1575;&#1583;&#1577; &#1575;&#1604;&#1601;&#1607;&#1585;&#1587;&#1577; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strreindexbad'] = '&#1604;&#1602;&#1583; &#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1573;&#1593;&#1575;&#1583;&#1577; &#1575;&#1604;&#1601;&#1607;&#1585;&#1587;&#1577;.';
 $lang['strfull'] = 'Full';
 $lang['strfreeze'] = 'Freeze';
 $lang['strforce'] = 'Force';

 // Views
 $lang['strview'] = 'View &#1593;&#1585;&#1590;';
 $lang['strviews'] = '&#1593;&#1585;&#1608;&#1590; Views';
 $lang['strshowallviews'] = '&#1571;&#1593;&#1585;&#1590; &#1580;&#1605;&#1610;&#1593; &#1575;&#1604;&#1593;&#1585;&#1608;&#1590; Views.';
 $lang['strnoview'] = '&#1604;&#1605; &#1610;&#1608;&#1580;&#1583; &#1593;&#1585;&#1590; View.';
 $lang['strnoviews'] = '&#1604;&#1605; &#1610;&#1608;&#1580;&#1583; &#1593;&#1585;&#1608;&#1590; Views.';
 $lang['strcreateview'] = '&#1573;&#1606;&#1588;&#1575;&#1569; &#1593;&#1585;&#1590; View &#1580;&#1583;&#1610;&#1583;';
 $lang['strviewname'] = '&#1573;&#1587;&#1605; &#1575;&#1604;&#1593;&#1585;&#1590; View';
 $lang['strviewneedsname'] = '&#1610;&#1580;&#1576; &#1573;&#1593;&#1591;&#1575;&#1569; &#1573;&#1587;&#1605; &#1604;&#1604;&#1593;&#1585;&#1590; View.';
 $lang['strviewneedsdef'] = '&#1610;&#1580;&#1576; &#1593;&#1604;&#1610;&#1603; &#1573;&#1593;&#1591;&#1575;&#1569; &#1578;&#1593;&#1585;&#1610;&#1601; &#1604;&#1604;&#1593;&#1585;&#1590; View.';
 $lang['strviewneedsfields'] = '&#1610;&#1580;&#1576; &#1593;&#1604;&#1610;&#1603; &#1578;&#1581;&#1583;&#1610;&#1583; &#1575;&#1604;&#1581;&#1602;&#1608;&#1604; &#1575;&#1604;&#1578;&#1610; &#1578;&#1585;&#1610;&#1583;&#1607;&#1575; &#1601;&#1610; &#1575;&#1604;&#1593;&#1585;&#1590; View.';
 $lang['strviewcreated'] = '&#1578;&#1605; &#1573;&#1606;&#1588;&#1575;&#1569; &#1575;&#1604;&#1593;&#1585;&#1590; View.';
 $lang['strviewcreatedbad'] = '&#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1573;&#1606;&#1588;&#1575;&#1569; &#1575;&#1604;&#1593;&#1585;&#1590; View.';
 $lang['strconfdropview'] = '&#1607;&#1604; &#1575;&#1606;&#1578; &#1605;&#1578;&#1571;&#1603;&#1583; &#1578;&#1585;&#1610;&#1583; &#1581;&#1584;&#1601; &#1575;&#1604;&#1593;&#1585;&#1590; View &#1576;&#1573;&#1587;&#1605; &quot;%s&quot;';
 $lang['strviewdropped'] = '&#1578;&#1605; &#1581;&#1584;&#1601; &#1575;&#1604;&#1593;&#1585;&#1590; View.';
 $lang['strviewdroppedbad'] = '&#1604;&#1602;&#1583; &#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1581;&#1584;&#1601; &#1575;&#1604;&#1593;&#1585;&#1590; View.';
 $lang['strviewupdated'] = '&#1578;&#1605; &#1578;&#1581;&#1583;&#1610;&#1579; &#1575;&#1604;&#1593;&#1585;&#1590; View &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strviewupdatedbad'] = '&#1604;&#1602;&#1583; &#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1578;&#1581;&#1583;&#1610;&#1579; &#1575;&#1604;&#1593;&#1585;&#1590; View.';
 $lang['strviewlink'] = 'Linking Keys';
 $lang['strviewconditions'] = 'Additional Conditions';
 $lang['strcreateviewwiz'] = '&#1573;&#1606;&#1588;&#1575;&#1569; &#1593;&#1585;&#1590; View &#1576;&#1573;&#1587;&#1578;&#1582;&#1583;&#1575;&#1605; &#1575;&#1604;&#1587;&#1575;&#1581;&#1585; Wizard.';

 // Sequences
 $lang['strsequence'] = '&#1578;&#1587;&#1604;&#1587;&#1604; Sequence';
 $lang['strsequences'] = '&#1578;&#1587;&#1604;&#1587;&#1604;&#1575;&#1578; Sequences';
 $lang['strshowallsequences'] = '&#1593;&#1585;&#1590; &#1580;&#1605;&#1610;&#1593; &#1575;&#1604;&#1578;&#1587;&#1604;&#1587;&#1604;&#1575;&#1578;';
 $lang['strnosequence'] = '&#1604;&#1605; &#1610;&#1608;&#1580;&#1583; &#1578;&#1587;&#1604;&#1587;&#1604;.';
 $lang['strnosequences'] = '&#1604;&#1605; &#1610;&#1608;&#1580;&#1583; &#1578;&#1587;&#1604;&#1587;&#1604;&#1575;&#1578;.';
 $lang['strcreatesequence'] = '&#1573;&#1606;&#1588;&#1575;&#1569; &#1578;&#1587;&#1604;&#1587;&#1604; &#1580;&#1583;&#1610;&#1583;';
 $lang['strlastvalue'] = '&#1570;&#1582;&#1585; &#1602;&#1610;&#1605;&#1577;';
 $lang['strincrementby'] = '&#1605;&#1602;&#1583;&#1575;&#1585; &#1575;&#1604;&#1586;&#1610;&#1575;&#1583;&#1577; Increment by'; 
 $lang['strstartvalue'] = '&#1602;&#1610;&#1605;&#1577; &#1575;&#1604;&#1576;&#1583;&#1575;&#1610;&#1577;';
 $lang['strmaxvalue'] = '&#1575;&#1604;&#1602;&#1610;&#1605;&#1577; &#1575;&#1604;&#1602;&#1589;&#1608;&#1609;';
 $lang['strminvalue'] = '&#1575;&#1604;&#1602;&#1610;&#1605;&#1577; &#1575;&#1604;&#1583;&#1606;&#1610;&#1575;';
 $lang['strcachevalue'] = 'Cache value';
 $lang['strlogcount'] = 'Log count';
 $lang['striscycled'] = 'Is cycled?';
 $lang['strsequenceneedsname'] = '&#1610;&#1580;&#1576; &#1573;&#1593;&#1591;&#1575;&#1569; &#1573;&#1587;&#1605; &#1604;&#1604;&#1578;&#1587;&#1604;&#1587;&#1604; sequence.';
 $lang['strsequencecreated'] = '&#1578;&#1605; &#1573;&#1606;&#1588;&#1575;&#1569; &#1575;&#1604;&#1578;&#1587;&#1604;&#1587;&#1604; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strsequencecreatedbad'] = '&#1604;&#1602;&#1583; &#1601;&#1588;&#1604; &#1573;&#1606;&#1588;&#1575;&#1569; &#1575;&#1604;&#1578;&#1587;&#1604;&#1587;&#1604;.'; 
 $lang['strconfdropsequence'] = '&#1607;&#1604; &#1571;&#1606;&#1578; &#1605;&#1578;&#1571;&#1603;&#1583; &#1578;&#1585;&#1610;&#1583; &#1581;&#1584;&#1601; &#1575;&#1604;&#1578;&#1587;&#1604;&#1587;&#1604; &#1576;&#1573;&#1587;&#1605; &quot;%s&quot;&#1567;';
 $lang['strsequencedropped'] = '&#1604;&#1602;&#1583; &#1578;&#1605; &#1581;&#1584;&#1601; &#1575;&#1604;&#1578;&#1587;&#1604;&#1587;&#1604; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strsequencedroppedbad'] = '&#1604;&#1602;&#1583; &#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1581;&#1584;&#1601; &#1575;&#1604;&#1578;&#1587;&#1604;&#1587;&#1604;.';
 $lang['strsequencereset'] = '&#1604;&#1602;&#1583; &#1578;&#1605;&#1578; &#1573;&#1593;&#1575;&#1583;&#1577; &#1575;&#1604;&#1578;&#1587;&#1604;&#1587;&#1604; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strsequenceresetbad'] = '&#1604;&#1602;&#1583; &#1601;&#1588;&#1604;&#1578; &#1573;&#1593;&#1575;&#1583;&#1577; &#1575;&#1604;&#1578;&#1587;&#1604;&#1587;&#1604;.'; 

 // Indexes
 $lang['strindex'] = '&#1601;&#1607;&#1585;&#1587;Index';
 $lang['strindexes'] = '&#1601;&#1607;&#1575;&#1585;&#1587;Indexes';
 $lang['strindexname'] = '&#1573;&#1587;&#1605; &#1575;&#1604;&#1601;&#1607;&#1585;&#1587; Index';
 $lang['strshowallindexes'] = '&#1593;&#1585;&#1590; &#1580;&#1605;&#1610;&#1593; &#1575;&#1604;&#1601;&#1607;&#1575;&#1585;&#1587; indexes';
 $lang['strnoindex'] = '&#1604;&#1605; &#1610;&#1608;&#1580;&#1583; &#1601;&#1607;&#1585;&#1587; index.';
 $lang['strnoindexes'] = '&#1604;&#1605; &#1578;&#1608;&#1580;&#1583; &#1601;&#1607;&#1575;&#1585;&#1587; indexes.';
 $lang['strcreateindex'] = '&#1573;&#1606;&#1588;&#1575;&#1569; &#1601;&#1607;&#1585;&#1587; index &#1580;&#1583;&#1610;&#1583;';
 $lang['strtabname'] = 'Tab name';
 $lang['strcolumnname'] = '&#1573;&#1587;&#1605; &#1575;&#1604;&#1593;&#1605;&#1608;&#1583;';
 $lang['strindexneedsname'] = '&#1610;&#1580;&#1576; &#1593;&#1604;&#1610;&#1603; &#1573;&#1593;&#1591;&#1575;&#1569; &#1573;&#1587;&#1605; &#1604;&#1604;&#1601;&#1607;&#1585;&#1587; index.';
 $lang['strindexneedscols'] = '&#1575;&#1604;&#1601;&#1607;&#1575;&#1585;&#1587; &#1578;&#1578;&#1591;&#1604;&#1576; &#1593;&#1583;&#1583; &#1605;&#1602;&#1576;&#1608;&#1604; &#1605;&#1606; &#1575;&#1604;&#1571;&#1593;&#1605;&#1583;&#1577;.';
 $lang['strindexcreated'] = '&#1604;&#1602;&#1583; &#1578;&#1605; &#1573;&#1606;&#1588;&#1575;&#1569; &#1575;&#1604;&#1601;&#1607;&#1585;&#1587; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strindexcreatedbad'] = '&#1601;&#1588;&#1604; &#1573;&#1606;&#1588;&#1575;&#1569; &#1575;&#1604;&#1601;&#1607;&#1585;&#1587;.';
 $lang['strconfdropindex'] = '&#1607;&#1604; &#1575;&#1606;&#1578; &#1605;&#1578;&#1571;&#1603;&#1583; &#1578;&#1585;&#1610;&#1583; &#1581;&#1584;&#1601; &#1575;&#1604;&#1601;&#1607;&#1585;&#1587; &#1576;&#1573;&#1587;&#1605; &quot;%s&quot;&#1567;';
 $lang['strindexdropped'] = '&#1604;&#1602;&#1583; &#1578;&#1605; &#1581;&#1584;&#1601; &#1575;&#1604;&#1601;&#1607;&#1585;&#1587; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strindexdroppedbad'] = '&#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1581;&#1584;&#1601; &#1575;&#1604;&#1601;&#1607;&#1585;&#1587;.';
 $lang['strkeyname'] = '&#1573;&#1587;&#1605; &#1575;&#1604;&#1605;&#1601;&#1578;&#1575;&#1581; Key';
 $lang['struniquekey'] = '&#1605;&#1601;&#1578;&#1575;&#1581; &#1601;&#1585;&#1610;&#1583; Unique key';
 $lang['strprimarykey'] = '&#1605;&#1601;&#1578;&#1575;&#1581; &#1585;&#1574;&#1610;&#1587;&#1610; Primary key';
  $lang['strindextype'] = '&#1606;&#1608;&#1593; &#1575;&#1604;&#1601;&#1607;&#1585;&#1587;';
 $lang['strtablecolumnlist'] = '&#1575;&#1604;&#1571;&#1593;&#1605;&#1583;&#1577; &#1601;&#1610; &#1575;&#1604;&#1580;&#1583;&#1608;&#1604;';
 $lang['strindexcolumnlist'] = '&#1575;&#1604;&#1571;&#1593;&#1605;&#1583;&#1577; &#1601;&#1610; &#1575;&#1604;&#1601;&#1607;&#1585;&#1587;';
 $lang['strconfcluster'] = 'Are you sure you want to cluster &quot;%s&quot;?';
 $lang['strclusteredgood'] = 'Cluster complete.';
 $lang['strclusteredbad'] = 'Cluster failed.';

 // Rules
 $lang['strrules'] = '&#1602;&#1608;&#1575;&#1593;&#1583; Rules';
 $lang['strrule'] = '&#1602;&#1575;&#1593;&#1583;&#1577; Rule';
 $lang['strshowallrules'] = '&#1593;&#1585;&#1590; &#1580;&#1605;&#1610;&#1593; &#1575;&#1604;&#1602;&#1608;&#1575;&#1593;&#1583;';
 $lang['strnorule'] = '&#1604;&#1605; &#1578;&#1608;&#1580;&#1583; &#1602;&#1575;&#1593;&#1583;&#1577;.';
 $lang['strnorules'] = '&#1604;&#1605; &#1578;&#1608;&#1580;&#1583; &#1602;&#1608;&#1575;&#1593;&#1583;.';
 $lang['strcreaterule'] = '&#1573;&#1606;&#1588;&#1575;&#1569; &#1602;&#1575;&#1593;&#1583;&#1577; rule &#1580;&#1583;&#1610;&#1583;&#1577;';
 $lang['strrulename'] = '&#1573;&#1587;&#1605; &#1575;&#1604;&#1602;&#1575;&#1593;&#1583;&#1577; rule name';
 $lang['strruleneedsname'] = '&#1610;&#1580;&#1576; &#1593;&#1604;&#1610;&#1603; &#1573;&#1593;&#1591;&#1575;&#1569; &#1573;&#1587;&#1605; &#1604;&#1604;&#1602;&#1575;&#1593;&#1583;&#1577; rule.';
 $lang['strrulecreated'] = '&#1578;&#1605; &#1573;&#1606;&#1588;&#1575;&#1569; &#1575;&#1604;&#1602;&#1575;&#1593;&#1583;&#1577; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strrulecreatedbad'] = '&#1601;&#1588;&#1604; &#1573;&#1606;&#1588;&#1575;&#1569; &#1575;&#1604;&#1602;&#1575;&#1593;&#1583;&#1577;.';
 $lang['strconfdroprule'] = '&#1607;&#1604; &#1571;&#1606;&#1578; &#1605;&#1578;&#1571;&#1603;&#1583; &#1578;&#1585;&#1610;&#1583; &#1581;&#1584;&#1601; &#1575;&#1604;&#1602;&#1575;&#1593;&#1583;&#1577; &quot;%s&quot; &#1593;&#1604;&#1609; &quot;%s&quot;&#1567;';
 $lang['strruledropped'] = '&#1578;&#1605; &#1581;&#1584;&#1601; &#1575;&#1604;&#1602;&#1575;&#1593;&#1583;&#1577;.';
 $lang['strruledroppedbad'] = '&#1601;&#1588;&#1604; &#1581;&#1584;&#1601; &#1575;&#1604;&#1602;&#1575;&#1593;&#1583;&#1577;.';

 // Constraints
 $lang['strconstraints'] = '&#1602;&#1610;&#1608;&#1583; Constraints';
 $lang['strshowallconstraints'] = '&#1593;&#1585;&#1590; &#1580;&#1605;&#1610;&#1593; &#1575;&#1604;&#1602;&#1610;&#1608;&#1583; constraints';
 $lang['strnoconstraints'] = '&#1604;&#1605; &#1610;&#1608;&#1580;&#1583; &#1602;&#1610;&#1608;&#1583; constraints.';
 $lang['strcreateconstraint'] = '&#1573;&#1606;&#1588;&#1575;&#1569; &#1602;&#1610;&#1583; constraint &#1580;&#1583;&#1610;&#1583;';
 $lang['strconstraintcreated'] = '&#1578;&#1605; &#1573;&#1606;&#1588;&#1575;&#1569; &#1575;&#1604;&#1602;&#1610;&#1583; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strconstraintcreatedbad'] = '&#1601;&#1588;&#1604; &#1573;&#1606;&#1588;&#1575;&#1569; &#1575;&#1604;&#1602;&#1610;&#1583;.';
 $lang['strconfdropconstraint'] = '&#1607;&#1604; &#1571;&#1606;&#1578; &#1605;&#1578;&#1571;&#1603;&#1583; &#1578;&#1585;&#1610;&#1583; &#1581;&#1584;&#1601; &#1575;&#1604;&#1602;&#1610;&#1583; &quot;%s&quot; &#1593;&#1604;&#1609; &quot;%s&quot;&#1567;';
 $lang['strconstraintdropped'] = '&#1578;&#1605; &#1581;&#1584;&#1601; &#1575;&#1604;&#1602;&#1610;&#1583; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strconstraintdroppedbad'] = '&#1601;&#1588;&#1604; &#1581;&#1584;&#1601; &#1575;&#1604;&#1602;&#1610;&#1583;.';
 $lang['straddcheck'] = '&#1573;&#1590;&#1575;&#1601;&#1577; &#1601;&#1581;&#1589; check';
 $lang['strcheckneedsdefinition'] = '&#1602;&#1610;&#1583; &#1575;&#1604;&#1601;&#1581;&#1589; &#1610;&#1581;&#1578;&#1575;&#1580; &#1604;&#1578;&#1593;&#1585;&#1610;&#1601;.';
 $lang['strcheckadded'] = '&#1578;&#1605; &#1573;&#1590;&#1575;&#1601;&#1577; &#1602;&#1610;&#1583; &#1575;&#1604;&#1601;&#1581;&#1589; &#1576;&#1606;&#1581;&#1575;&#1581;.';
 $lang['strcheckaddedbad'] = '&#1601;&#1588;&#1604;&#1578; &#1573;&#1590;&#1575;&#1601;&#1577; &#1602;&#1610;&#1583; &#1575;&#1604;&#1601;&#1581;&#1589;.';
 $lang['straddpk'] = 'primary key &#1573;&#1590;&#1575;&#1601;&#1577; &#1605;&#1601;&#1578;&#1575;&#1581; &#1585;&#1574;&#1610;&#1587;&#1610;.';
 $lang['strpkneedscols'] = '&#1575;&#1604;&#1605;&#1601;&#1578;&#1575;&#1581; &#1575;&#1604;&#1585;&#1574;&#1610;&#1587;&#1610; &#1610;&#1578;&#1591;&#1604;&#1576; &#1593;&#1604;&#1609; &#1575;&#1604;&#1571;&#1602;&#1604; &#1593;&#1605;&#1608;&#1583; &#1608;&#1575;&#1581;&#1583;.';
 $lang['strpkadded'] = '&#1578;&#1605;&#1578; &#1573;&#1590;&#1575;&#1601;&#1577; &#1575;&#1604;&#1605;&#1601;&#1578;&#1575;&#1581; &#1575;&#1604;&#1585;&#1574;&#1610;&#1587;&#1610; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strpkaddedbad'] = '&#1601;&#1588;&#1604;&#1578; &#1573;&#1590;&#1575;&#1601;&#1577; &#1575;&#1604;&#1605;&#1601;&#1578;&#1575;&#1581; &#1575;&#1604;&#1585;&#1574;&#1610;&#1587;&#1610;.';
 $lang['stradduniq'] = 'unique key &#1573;&#1590;&#1575;&#1601;&#1577; &#1605;&#1601;&#1578;&#1575;&#1581; &#1601;&#1585;&#1610;&#1583;';
 $lang['struniqneedscols'] = '&#1575;&#1604;&#1605;&#1601;&#1578;&#1575;&#1581; &#1575;&#1604;&#1601;&#1585;&#1610;&#1583; &#1610;&#1578;&#1591;&#1604;&#1576; &#1593;&#1605;&#1608;&#1583; &#1608;&#1575;&#1581;&#1583; &#1593;&#1604;&#1609; &#1575;&#1604;&#1571;&#1602;&#1604;.';
 $lang['struniqadded'] = '&#1578;&#1605;&#1578; &#1573;&#1590;&#1575;&#1601;&#1577; &#1575;&#1604;&#1605;&#1601;&#1578;&#1575;&#1581; &#1575;&#1604;&#1601;&#1585;&#1610;&#1583; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['struniqaddedbad'] = '&#1601;&#1588;&#1604;&#1578; &#1573;&#1590;&#1575;&#1601;&#1577; &#1575;&#1604;&#1605;&#1601;&#1578;&#1575;&#1581; &#1575;&#1604;&#1601;&#1585;&#1610;&#1583;.';
 $lang['straddfk'] = '&#1573;&#1590;&#1575;&#1601;&#1577; &#1605;&#1601;&#1578;&#1575;&#1581; &#1582;&#1575;&#1585;&#1580;&#1610;foreign key';
 $lang['strfkneedscols'] = '&#1575;&#1604;&#1605;&#1601;&#1578;&#1575;&#1581; &#1575;&#1604;&#1582;&#1575;&#1585;&#1580;&#1610; &#1610;&#1578;&#1591;&#1604;&#1576; &#1593;&#1605;&#1608;&#1583; &#1608;&#1575;&#1581;&#1583; &#1593;&#1604;&#1609; &#1575;&#1604;&#1571;&#1602;&#1604;.';
 $lang['strfkneedstarget'] = '&#1575;&#1604;&#1605;&#1601;&#1578;&#1575;&#1581; &#1575;&#1604;&#1582;&#1575;&#1585;&#1580;&#1610; &#1610;&#1581;&#1578;&#1575;&#1580; &#1575;&#1604;&#1609; &#1580;&#1583;&#1608;&#1604; &#1607;&#1583;&#1601;.';
 $lang['strfkadded'] = '&#1578;&#1605;&#1578; &#1573;&#1590;&#1575;&#1601;&#1577; &#1575;&#1604;&#1605;&#1601;&#1578;&#1575;&#1581; &#1575;&#1604;&#1582;&#1575;&#1585;&#1580;&#1610; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strfkaddedbad'] = '&#1601;&#1588;&#1604;&#1578; &#1573;&#1590;&#1575;&#1601;&#1577; &#1575;&#1604;&#1605;&#1601;&#1578;&#1575;&#1581; &#1575;&#1604;&#1582;&#1575;&#1585;&#1580;&#1610;.';
 $lang['strfktarget'] = '&#1575;&#1604;&#1580;&#1583;&#1608;&#1604; &#1575;&#1604;&#1607;&#1583;&#1601; Target table';
 $lang['strfkcolumnlist'] = '&#1575;&#1604;&#1571;&#1593;&#1605;&#1583;&#1577; &#1601;&#1610; &#1575;&#1604;&#1605;&#1601;&#1578;&#1575;&#1581;';
 $lang['strondelete'] = 'ON DELETE';
 $lang['stronupdate'] = 'ON UPDATE';

 // Functions
 $lang['strfunction'] = '&#1583;&#1575;&#1604;&#1577; Function';
 $lang['strfunctions'] = '&#1583;&#1608;&#1575;&#1604; Functions';
 $lang['strshowallfunctions'] = '&#1593;&#1585;&#1590; &#1580;&#1605;&#1610;&#1593; &#1575;&#1604;&#1583;&#1608;&#1575;&#1604; functions';
 $lang['strnofunction'] = '&#1604;&#1605; &#1578;&#1608;&#1580;&#1583; &#1583;&#1575;&#1604;&#1577; function.';
 $lang['strnofunctions'] = '&#1604;&#1605; &#1578;&#1608;&#1580;&#1583; &#1583;&#1608;&#1575;&#1604; functions.';
 $lang['strfunctionname'] = '&#1573;&#1587;&#1605; &#1575;&#1604;&#1583;&#1575;&#1604;&#1577; function name';
 $lang['strreturns'] = 'Returns';
 $lang['strarguments'] = 'Arguments';
 $lang['strproglanguage'] = '&#1604;&#1594;&#1577; &#1576;&#1585;&#1605;&#1580;&#1577;';
 $lang['strfunctionneedsname'] = '&#1610;&#1580;&#1576; &#1593;&#1604;&#1610;&#1603; &#1573;&#1593;&#1591;&#1575;&#1569; &#1573;&#1587;&#1605; &#1604;&#1604;&#1583;&#1575;&#1604;&#1577; function.';
 $lang['strfunctionneedsdef'] = '&#1610;&#1580;&#1576; &#1593;&#1604;&#1610;&#1603; &#1575;&#1593;&#1591;&#1575;&#1569; &#1578;&#1593;&#1585;&#1610;&#1601; &#1604;&#1604;&#1583;&#1575;&#1604;&#1577; function definition.';
 $lang['strfunctioncreated'] = '&#1578;&#1605; &#1573;&#1606;&#1588;&#1575;&#1569; &#1575;&#1604;&#1583;&#1575;&#1604;&#1577; function &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strfunctioncreatedbad'] = '&#1604;&#1602;&#1583; &#1601;&#1588;&#1604; &#1573;&#1606;&#1588;&#1575;&#1569; &#1575;&#1604;&#1583;&#1575;&#1604;&#1577;.';
 $lang['strconfdropfunction'] = '&#1607;&#1604; &#1571;&#1606;&#1578; &#1605;&#1578;&#1571;&#1603;&#1583; &#1578;&#1585;&#1610;&#1583; &#1581;&#1584;&#1601; &#1575;&#1604;&#1583;&#1575;&#1604;&#1577; function &#1576;&#1573;&#1587;&#1605; &quot;%s&quot;?';
 $lang['strfunctiondropped'] = '&#1578;&#1605; &#1581;&#1584;&#1601; &#1575;&#1604;&#1583;&#1575;&#1604;&#1577; function &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strfunctiondroppedbad'] = '&#1604;&#1602;&#1583; &#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1581;&#1584;&#1601; &#1575;&#1604;&#1583;&#1575;&#1604;&#1577; function.';
 $lang['strfunctionupdated'] = '&#1604;&#1602;&#1583; &#1578;&#1605; &#1578;&#1593;&#1583;&#1610;&#1604; &#1575;&#1604;&#1583;&#1575;&#1604;&#1577; function.';
 $lang['strfunctionupdatedbad'] = '&#1604;&#1602;&#1583; &#1601;&#1588;&#1604; &#1578;&#1593;&#1583;&#1610;&#1604; &#1575;&#1604;&#1583;&#1575;&#1604;&#1577; function.';

 // Triggers
 $lang['strtrigger'] = '&#1605;&#1581;&#1601;&#1617;&#1586; Trigger';
 $lang['strtriggers'] = '&#1605;&#1581;&#1601;&#1617;&#1586;&#1575;&#1578; Triggers';
 $lang['strshowalltriggers'] = '&#1593;&#1585;&#1590; &#1580;&#1605;&#1610;&#1593; &#1575;&#1604;&#1605;&#1581;&#1601;&#1586;&#1575;&#1578; triggers';
 $lang['strnotrigger'] = '&#1604;&#1605; &#1610;&#1608;&#1580;&#1583; &#1575;&#1604;&#1605;&#1581;&#1601;&#1586; trigger.';
 $lang['strnotriggers'] = '&#1604;&#1605; &#1610;&#1608;&#1580;&#1583; &#1605;&#1581;&#1601;&#1586;&#1575;&#1578; triggers.';
 $lang['strcreatetrigger'] = '&#1573;&#1606;&#1588;&#1575;&#1569; &#1605;&#1581;&#1601;&#1617;&#1586; trigger &#1580;&#1583;&#1610;&#1583;';
 $lang['strtriggerneedsname'] = '&#1610;&#1580;&#1576; &#1573;&#1593;&#1591;&#1575;&#1569; &#1575;&#1587;&#1605; &#1604;&#1604;&#1605;&#1581;&#1601;&#1586;.';
 $lang['strtriggerneedsfunc'] = '&#1610;&#1580;&#1576; &#1578;&#1581;&#1583;&#1610;&#1583; &#1583;&#1575;&#1604;&#1577; function &#1604;&#1604;&#1605;&#1581;&#1601;&#1586;.';
 $lang['strtriggercreated'] = '&#1578;&#1605; &#1573;&#1606;&#1588;&#1575;&#1569; &#1575;&#1604;&#1605;&#1581;&#1601;&#1586; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strtriggercreatedbad'] = '&#1604;&#1602;&#1583; &#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1573;&#1606;&#1588;&#1575;&#1569; &#1575;&#1604;&#1605;&#1581;&#1601;&#1586;.';
 $lang['strconfdroptrigger'] = '&#1607;&#1604; &#1571;&#1606;&#1578; &#1605;&#1578;&#1571;&#1603;&#1583; &#1578;&#1585;&#1610;&#1583; &#1581;&#1584;&#1601; &#1575;&#1604;&#1605;&#1581;&#1601;&#1617;&#1586; trigger &quot;%s&quot; &#1593;&#1604;&#1609; &quot;%s&quot;&#1567;';
 $lang['strtriggerdropped'] = '&#1578;&#1605; &#1581;&#1584;&#1601; &#1575;&#1604;&#1605;&#1581;&#1601;&#1586;.';
 $lang['strtriggerdroppedbad'] = '&#1601;&#1588;&#1604; &#1581;&#1584;&#1601; &#1575;&#1604;&#1605;&#1581;&#1601;&#1586;&#1548; &#1604;&#1605; &#1610;&#1578;&#1605; &#1575;&#1604;&#1581;&#1584;&#1601;.';
 $lang['strtriggeraltered'] = '&#1578;&#1605; &#1578;&#1593;&#1583;&#1610;&#1604; &#1575;&#1604;&#1605;&#1581;&#1601;&#1586; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strtriggeralteredbad'] = '&#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1578;&#1593;&#1583;&#1610;&#1604; &#1575;&#1604;&#1605;&#1581;&#1601;&#1586;. &#1604;&#1605; &#1610;&#1578;&#1605; &#1575;&#1604;&#1578;&#1593;&#1583;&#1610;&#1604;.';

 // Types
 $lang['strtype'] = '&#1606;&#1608;&#1593; Type';
 $lang['strtypes'] = '&#1571;&#1606;&#1608;&#1575;&#1593; Types';
 $lang['strshowalltypes'] = '&#1593;&#1585;&#1590; &#1580;&#1605;&#1610;&#1593; &#1575;&#1604;&#1571;&#1606;&#1608;&#1575;&#1593;';
 $lang['strnotype'] = '&#1604;&#1605; &#1610;&#1608;&#1580;&#1583; &#1575;&#1604;&#1606;&#1608;&#1593;.';
 $lang['strnotypes'] = '&#1604;&#1605; &#1610;&#1608;&#1580;&#1583; &#1571;&#1606;&#1608;&#1575;&#1593;.';
 $lang['strcreatetype'] = '&#1573;&#1606;&#1588;&#1575;&#1569; &#1606;&#1608;&#1593; &#1580;&#1583;&#1610;&#1583;.';
 $lang['strtypename'] = '&#1573;&#1587;&#1605; &#1575;&#1604;&#1606;&#1608;&#1593;';
 $lang['strinputfn'] = '&#1583;&#1575;&#1604;&#1577; &#1575;&#1604;&#1573;&#1583;&#1582;&#1575;&#1604; Input function';
 $lang['stroutputfn'] = '&#1583;&#1575;&#1604;&#1577; &#1575;&#1604;&#1573;&#1582;&#1585;&#1575;&#1580; Output function';
 $lang['strpassbyval'] = 'Passed by val?';
 $lang['stralignment'] = 'Alignment';
 $lang['strelement'] = 'Element';
 $lang['strdelimiter'] = 'Delimiter';
 $lang['strstorage'] = 'Storage';
 $lang['strtypeneedsname'] = '&#1610;&#1580;&#1576; &#1573;&#1593;&#1591;&#1575;&#1569; &#1573;&#1587;&#1605; &#1604;&#1604;&#1606;&#1608;&#1593;.';
 $lang['strtypeneedslen'] = '&#1610;&#1580;&#1576; &#1573;&#1593;&#1591;&#1575;&#1569; &#1591;&#1608;&#1604; &#1604;&#1604;&#1606;&#1608;&#1593;.';
 $lang['strtypecreated'] = '&#1578;&#1605; &#1573;&#1606;&#1588;&#1575;&#1569; &#1575;&#1604;&#1606;&#1608;&#1593;';
 $lang['strtypecreatedbad'] = '&#1601;&#1588;&#1604; &#1573;&#1606;&#1588;&#1575;&#1569; &#1575;&#1604;&#1606;&#1608;&#1593;.';
 $lang['strconfdroptype'] = '&#1607;&#1604; &#1571;&#1606;&#1578; &#1605;&#1578;&#1571;&#1603;&#1583; &#1578;&#1585;&#1610;&#1583; &#1581;&#1584;&#1601; &#1575;&#1604;&#1606;&#1608;&#1593; &quot;%s&quot;&#1567;';
 $lang['strtypedropped'] = '&#1578;&#1605; &#1581;&#1584;&#1601; &#1575;&#1604;&#1606;&#1608;&#1593;.';
 $lang['strtypedroppedbad'] = '&#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1581;&#1584;&#1601; &#1575;&#1604;&#1606;&#1608;&#1593;.';

 // Schemas
 $lang['strschema'] = '&#1605;&#1582;&#1591;&#1591; Schema';
 $lang['strschemas'] = '&#1575;&#1604;&#1605;&#1582;&#1591;&#1591;&#1575;&#1578; Schemas';
 $lang['strshowallschemas'] = '&#1593;&#1585;&#1590; &#1580;&#1605;&#1610;&#1593; &#1575;&#1604;&#1605;&#1582;&#1591;&#1591;&#1575;&#1578; schemas';
 $lang['strnoschema'] = '&#1604;&#1605; &#1610;&#1608;&#1580;&#1583; &#1605;&#1582;&#1591;&#1591; schema.';
 $lang['strnoschemas'] = '&#1604;&#1605; &#1578;&#1608;&#1580;&#1583; &#1605;&#1582;&#1591;&#1591;&#1575;&#1578; schemas.';
 $lang['strcreateschema'] = '&#1573;&#1606;&#1588;&#1575;&#1569; &#1605;&#1582;&#1591;&#1591; schema &#1580;&#1583;&#1610;&#1583;';
 $lang['strschemaname'] = '&#1573;&#1587;&#1605; &#1575;&#1604;&#1605;&#1582;&#1591;&#1591;';
 $lang['strschemaneedsname'] = '&#1610;&#1580;&#1576; &#1593;&#1604;&#1610;&#1603; &#1573;&#1593;&#1591;&#1575;&#1569; &#1573;&#1587;&#1605; &#1604;&#1604;&#1605;&#1582;&#1591;&#1591;.';
 $lang['strschemacreated'] = '&#1604;&#1602;&#1583; &#1578;&#1605; &#1575;&#1606;&#1588;&#1575;&#1569; &#1575;&#1604;&#1605;&#1582;&#1591;&#1591; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strschemacreatedbad'] = '&#1601;&#1588;&#1604; &#1573;&#1606;&#1588;&#1575;&#1569; &#1575;&#1604;&#1605;&#1582;&#1591;&#1591;.';
 $lang['strconfdropschema'] = '&#1607;&#1604; &#1571;&#1606;&#1578; &#1605;&#1578;&#1571;&#1603;&#1583; &#1578;&#1585;&#1610;&#1583; &#1581;&#1584;&#1601; &#1575;&#1604;&#1605;&#1582;&#1591;&#1591; Schema &#1576;&#1573;&#1587;&#1605; &quot;%s&quot;&#1567;';
 $lang['strschemadropped'] = '&#1578;&#1605; &#1581;&#1584;&#1601; &#1575;&#1604;&#1605;&#1582;&#1591;&#1591;.';
 $lang['strschemadroppedbad'] = '&#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1575;&#1604;&#1581;&#1584;&#1601; &#1604;&#1604;&#1605;&#1582;&#1591;&#1591;.';
 $lang['strschemaaltered'] = '&#1578;&#1605; &#1578;&#1593;&#1583;&#1610;&#1604; &#1575;&#1604;&#1605;&#1582;&#1591;&#1591;.';
 $lang['strschemaalteredbad'] = '&#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1578;&#1593;&#1583;&#1610;&#1604; &#1575;&#1604;&#1605;&#1582;&#1591;&#1591;&#1548; &#1604;&#1605; &#1610;&#1578;&#1605; &#1575;&#1604;&#1578;&#1593;&#1583;&#1610;&#1604;.';

 // Reports
 $lang['strreport'] = '&#1578;&#1602;&#1585;&#1610;&#1585; Report';
 $lang['strreports'] = '&#1578;&#1602;&#1575;&#1585;&#1610;&#1585; Reports';
 $lang['strshowallreports'] = '&#1593;&#1585;&#1590; &#1580;&#1605;&#1610;&#1593; &#1575;&#1604;&#1578;&#1602;&#1575;&#1585;&#1610;&#1585;';
 $lang['strnoreports'] = '&#1604;&#1605; &#1578;&#1608;&#1580;&#1583; &#1578;&#1602;&#1575;&#1585;&#1610;&#1585;.';
 $lang['strcreatereport'] = '&#1573;&#1606;&#1588;&#1575;&#1569; &#1578;&#1602;&#1585;&#1610;&#1585; &#1580;&#1583;&#1610;&#1583;';
 $lang['strreportdropped'] = '&#1578;&#1605; &#1581;&#1584;&#1601; &#1575;&#1604;&#1578;&#1602;&#1585;&#1610;&#1585;.';
 $lang['strreportdroppedbad'] = '&#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1581;&#1584;&#1601; &#1575;&#1604;&#1578;&#1602;&#1585;&#1610;&#1585;.';
 $lang['strconfdropreport'] = '&#1607;&#1604; &#1571;&#1606;&#1578; &#1605;&#1578;&#1571;&#1603;&#1583; &#1578;&#1585;&#1610;&#1583; &#1581;&#1584;&#1601; &#1575;&#1604;&#1578;&#1602;&#1585;&#1610;&#1585; &quot;%s&quot;&#1567;';
 $lang['strreportneedsname'] = '&#1610;&#1580;&#1576; &#1573;&#1593;&#1591;&#1575;&#1569; &#1575;&#1587;&#1605; &#1604;&#1604;&#1578;&#1602;&#1585;&#1610;&#1585;.';
 $lang['strreportneedsdef'] = '&#1610;&#1580;&#1576; &#1603;&#1578;&#1575;&#1576;&#1577; &#1593;&#1576;&#1575;&#1585;&#1577; SQL &#1604;&#1604;&#1578;&#1602;&#1585;&#1610;&#1585;.';
 $lang['strreportcreated'] = '&#1578;&#1605; &#1581;&#1601;&#1592; &#1575;&#1604;&#1578;&#1602;&#1585;&#1610;&#1585;.';
 $lang['strreportcreatedbad'] = '&#1604;&#1605; &#1610;&#1578;&#1605; &#1581;&#1601;&#1592; &#1575;&#1604;&#1578;&#1602;&#1585;&#1610;&#1585;&#1548; &#1604;&#1602;&#1583; &#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1575;&#1604;&#1581;&#1601;&#1592;.';

 // Domains
 $lang['strdomain'] = '&#1606;&#1591;&#1575;&#1602; Domain';
 $lang['strdomains'] = '&#1606;&#1591;&#1575;&#1602;&#1575;&#1578; Domains';
 $lang['strshowalldomains'] = '&#1593;&#1585;&#1590; &#1580;&#1610;&#1593; &#1575;&#1604;&#1606;&#1591;&#1575;&#1602;&#1575;&#1578;';
 $lang['strnodomains'] = '&#1604;&#1605; &#1610;&#1608;&#1580;&#1583; &#1606;&#1591;&#1575;&#1602;&#1575;&#1578;.';
 $lang['strcreatedomain'] = '&#1573;&#1606;&#1588;&#1575;&#1569; &#1606;&#1591;&#1575;&#1602; &#1580;&#1583;&#1610;&#1583;';
 $lang['strdomaindropped'] = '&#1578;&#1605; &#1581;&#1584;&#1601; &#1575;&#1604;&#1606;&#1591;&#1575;&#1602;.';
 $lang['strdomaindroppedbad'] = '&#1604;&#1602;&#1583; &#1601;&#1588;&#1604; &#1581;&#1584;&#1601; &#1575;&#1604;&#1606;&#1591;&#1575;&#1602;&#1548; &#1604;&#1605; &#1610;&#1578;&#1605; &#1575;&#1604;&#1581;&#1584;&#1601;.';
 $lang['strconfdropdomain'] = '&#1607;&#1604; &#1571;&#1606;&#1578; &#1605;&#1578;&#1571;&#1603;&#1583; &#1578;&#1585;&#1610;&#1583; &#1581;&#1584;&#1601; &#1575;&#1604;&#1606;&#1591;&#1575;&#1602; domain &#1576;&#1573;&#1587;&#1605; &quot;%s&quot;&#1567;';
 $lang['strdomainneedsname'] = '&#1610;&#1580;&#1576; &#1573;&#1593;&#1591;&#1575;&#1569; &#1573;&#1587;&#1605; &#1604;&#1604;&#1606;&#1591;&#1575;&#1602;.';
 $lang['strdomaincreated'] = '&#1578;&#1605; &#1573;&#1606;&#1588;&#1575;&#1569; &#1575;&#1604;&#1606;&#1591;&#1575;&#1602; &#1576;&#1606;&#1580;&#1575;&#1581;.';
 $lang['strdomaincreatedbad'] = '&#1604;&#1605; &#1610;&#1578;&#1605; &#1573;&#1606;&#1588;&#1575;&#1569; &#1575;&#1604;&#1606;&#1591;&#1575;&#1602;&#1548; &#1601;&#1588;&#1604;&#1578; &#1575;&#1604;&#1593;&#1605;&#1604;&#1610;&#1577;.'; 
 $lang['strdomainaltered'] = '&#1578;&#1605; &#1578;&#1593;&#1583;&#1610;&#1604; &#1575;&#1604;&#1606;&#1591;&#1575;&#1602;.';
 $lang['strdomainalteredbad'] = '&#1601;&#1588;&#1604;&#1578; &#1593;&#1605;&#1604;&#1610;&#1577; &#1578;&#1593;&#1583;&#1610;&#1604; &#1575;&#1604;&#1606;&#1591;&#1575;&#1602;.'; 

 // Operators
 $lang['stroperator'] = 'Operator';
 $lang['stroperators'] = 'Operators';
 $lang['strshowalloperators'] = 'Show all operators';
 $lang['strnooperator'] = 'No operator found.';
 $lang['strnooperators'] = 'No operators found.';
 $lang['strcreateoperator'] = 'Create operator';
 $lang['strleftarg'] = 'Left Arg Type';
 $lang['strrightarg'] = 'Right Arg Type';
 $lang['strcommutator'] = 'Commutator';
 $lang['strnegator'] = 'Negator';
 $lang['strrestrict'] = 'Restrict';
 $lang['strjoin'] = 'Join';
 $lang['strhashes'] = 'Hashes';
 $lang['strmerges'] = 'Merges';
 $lang['strleftsort'] = 'Left sort';
 $lang['strrightsort'] = 'Right sort';
 $lang['strlessthan'] = 'Less than';
 $lang['strgreaterthan'] = 'Greater than';
 $lang['stroperatorneedsname'] = 'You must give a name for your operator.';
 $lang['stroperatorcreated'] = 'Operator created';
 $lang['stroperatorcreatedbad'] = 'Operator creation failed.';
 $lang['strconfdropoperator'] = 'Are you sure you want to drop the operator &quot;%s&quot;?';
 $lang['stroperatordropped'] = 'Operator dropped.';
 $lang['stroperatordroppedbad'] = 'Operator drop failed.';

 // Casts
 $lang['strcasts'] = 'Casts';
 $lang['strnocasts'] = 'No casts found.';
 $lang['strsourcetype'] = 'Source type';
 $lang['strtargettype'] = 'Target type';
 $lang['strimplicit'] = 'Implicit';
 $lang['strinassignment'] = 'In assignment';
 $lang['strbinarycompat'] = '(Binary compatible)';
 
 // Conversions
 $lang['strconversions'] = 'Conversions';
 $lang['strnoconversions'] = 'No conversions found.';
 $lang['strsourceencoding'] = 'Source encoding';
 $lang['strtargetencoding'] = 'Target encoding';
 
 // Languages
 $lang['strlanguages'] = 'Languages';
 $lang['strnolanguages'] = 'No languages found.';
 $lang['strtrusted'] = 'Trusted';
 
 // Info
 $lang['strnoinfo'] = 'No information available.';
 $lang['strreferringtables'] = 'Referring tables';
 $lang['strparenttables'] = 'Parent tables';
 $lang['strchildtables'] = 'Child tables';
 
 // Aggregates
 $lang['straggregates'] = 'Aggregates';
 $lang['strnoaggregates'] = 'No aggregates found.';
 $lang['stralltypes'] = '(All types)';

 // Operator Classes
 $lang['stropclasses'] = 'Op Classes';
 $lang['strnoopclasses'] = 'No operator classes found.';
 $lang['straccessmethod'] = 'Access method';

 // Stats and performance
 $lang['strrowperf'] = 'Row Performance';
 $lang['strioperf'] = 'I/O Performance';
 $lang['stridxrowperf'] = 'Index Row Performance';
 $lang['stridxioperf'] = 'Index I/O Performance';
 $lang['strpercent'] = '%';
 $lang['strsequential'] = 'Sequential';
 $lang['strscan'] = 'Scan';
 $lang['strread'] = 'Read';
 $lang['strfetch'] = 'Fetch';
 $lang['strheap'] = 'Heap';
 $lang['strtoast'] = 'TOAST';
 $lang['strtoastindex'] = 'TOAST Index';
 $lang['strcache'] = 'Cache';
 $lang['strdisk'] = 'Disk';
 $lang['strrows2'] = 'Rows';

 // Miscellaneous
 $lang['strtopbar'] = '%s &#1610;&#1593;&#1605;&#1604; &#1593;&#1604;&#1609; %s:%s -- You are logged in as user &quot;%s&quot;';
 $lang['strtimefmt'] = 'jS M, Y g:iA';
 $lang['strhelp'] = '&#1605;&#1587;&#1575;&#1593;&#1583;&#1577;';

?>
